@@ -32,7 +32,7 @@ class SemanticCompare:
         
     def build_input(
         self, label_1="Sentence I", label_2="Sentence II", button="⇆ Compare", spinner_msg = "Wait for it...", 
-        sentences: Optional[Tuple[str, str]] = ["", ""]
+        sentences: Optional[Tuple[str, str]] = ("", "")
     ):
         self.__first_text = sentences[0]
         self.__second_text = sentences[1]
